==> am_mod_grp_0_3.zip: am_mod_grp_0_3/components/grp/config/grp.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// group type
$group_config['type']['open'] = 							1; // auto registration
$group_config['type']['approved'] = 						2; // registration approval
$group_config['type']['invitation'] = 						3; // invitation only
$group_config['type']['membership_type'] = 					4; // membership type access only


// publishing levels
$group_config['level']['registered'] = 						4;
$group_config['level']['public'] = 							16;


// GROUP PERMISSIONS
// contributors
$group_config['resource']['user']['add_annoucements'] = 	1;
$group_config['resource']['user']['manage_participants'] = 	2;
$group_config['resource']['user']['add_polls'] = 			4;
$group_config['resource']['user']['allow_invite'] = 		8;
$group_config['resource']['user']['manage_subjects'] = 		16; // lock and sticky

// set the default permissions for new registrants
$group_config['default_participation_permission'] = 		0;


// group status
$group_config['status']['live'] = 							1;
$group_config['status']['archive'] = 						2;


// group roles
$group_config['role']['coordinator'] = 						1;


// files
$group_config['default_file_allocation'] = 					20000; // 20kb


// statistics
$group_config['statistic']['total_subjects'] = 				1;
$group_config['statistic']['total_comments'] = 				2;


// TAG TYPE CONFIGURATION
$group_config['tag']['grp']['group'] = 						1;
$group_config['tag']['grp']['subject'] = 					2;


// virtual domain for group (leave blank if direct url link forbidden)
$group_config['url']['v_group'] = 			"http://groups.your-domain.org/";

?>

==> am_mod_grp_0_5.zip: am_mod_grp_0_5/components/grp/config/grp.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// group type
$group_config['type']['open'] = 							1; // auto registration
$group_config['type']['approved'] = 						2; // registration approval
$group_config['type']['invitation'] = 						3; // invitation only
$group_config['type']['membership_type'] = 					4; // membership type access only


// publishing levels
$group_config['level']['registered'] = 						4;
$group_config['level']['public'] = 							16;


// GROUP PERMISSIONS
// contributors
$group_config['resource']['user']['add_annoucements'] = 	1;
$group_config['resource']['user']['manage_participants'] = 	2;
$group_config['resource']['user']['add_polls'] = 			4;
$group_config['resource']['user']['allow_invite'] = 		8;
$group_config['resource']['user']['manage_subjects'] = 		16; // lock and sticky

// set the default permissions for new registrants
$group_config['default_participation_permission'] = 		0;


// group status
$group_config['status']['live'] = 							1;
$group_config['status']['archive'] = 						2;
$group_config['status']['pending'] = 						3;

$group_config['creation_default_status'] = 					3;

// allow the owner to change status to live (if creation_default_status is not live)
// 1= allow, 0=deny
$group_config['owner_allow_to_live_status'] = 				1;


// group roles
$group_config['role']['coordinator'] = 						1;


// files
$group_config['default_file_allocation'] = 					20000; // 20kb


// statistics
$group_config['statistic']['total_subjects'] = 				1;
$group_config['statistic']['total_comments'] = 				2;


// TAG TYPE CONFIGURATION
$group_config['tag']['grp']['group'] = 						1;
$group_config['tag']['grp']['subject'] = 					2;


// virtual domain for group (leave blank if direct url link forbidden)
$group_config['url']['v_group'] = 			"http://groups.your-domain.org/";

?>
